@@ -1,4 +1,5 @@
 import os
+import sys
 import argparse
 import yaml
 from create_py_app.create_files import (
@@ -13,7 +14,8 @@ def main():
     parser.add_argument("--name", required=True, type=str)
     app_name = parser.parse_args().name
     base_dir = create_dir(os.getcwd(), app_name)
-    with open("../create_py_app/file_contents.yml", "r") as f:
+    yaml_path = os.path.dirname(sys.argv[0])
+    with open(yaml_path + "file_contents.yml", "r") as f:
         yaml_data = yaml.safe_load(f)
         for key in yaml_data.keys():
             if key in ["README.md", "pyproject.toml"]:
